@@ -4,7 +4,8 @@ require 'gitlab/version'
 require 'gitlab/objectified_hash'
 require 'gitlab/configuration'
 require 'gitlab/error'
-require 'gitlab/page_links'
+require 'gitlab/headers/page_links'
+require 'gitlab/headers/total'
 require 'gitlab/paginated_response'
 require 'gitlab/file_response'
 require 'gitlab/request'
@@ -21,11 +22,18 @@ module Gitlab
     Gitlab::Client.new(options)
   end
 
-  # Delegate to Gitlab::Client
-  def self.method_missing(method, *args, &block)
-    return super unless client.respond_to?(method)
+  if Gem::Version.new(RUBY_VERSION).release >= Gem::Version.new('3.0.0')
+    def self.method_missing(method, *args, **keywargs, &block)
+      return super unless client.respond_to?(method)
 
-    client.send(method, *args, &block)
+      client.send(method, *args, **keywargs, &block)
+    end
+  else
+    def self.method_missing(method, *args, &block)
+      return super unless client.respond_to?(method)
+
+      client.send(method, *args, &block)
+    end
   end
 
   # Delegate to Gitlab::Client
@@ -42,8 +50,10 @@ module Gitlab
   #
   # @return [Array<Symbol>]
   def self.actions
+    # rubocop:disable Layout/LineLength
     hidden =
-      /endpoint|private_token|auth_token|user_agent|sudo|get|post|put|\Adelete\z|validate\z|request_defaults|httparty/
+      /endpoint|private_token|auth_token|user_agent|sudo|get|post|put|patch|\Adelete\z|validate\z|request_defaults|httparty/
+    # rubocop:enable Layout/LineLength
     (Gitlab::Client.instance_methods - Object.methods).reject { |e| e[hidden] }
   end
 end
