@@ -3,7 +3,7 @@
 class Gitlab::Client
   # Defines methods related to projects.
   # @see https://docs.gitlab.com/ce/api/projects.html
-  module Projects
+  module Projects # rubocop:disable Metrics/ModuleLength
     # Gets a list of projects owned by the authenticated user.
     #
     # @example
@@ -44,9 +44,12 @@ class Gitlab::Client
     #   Gitlab.project('gitlab')
     #
     # @param  [Integer, String] id The ID or path of a project.
+    # @param  options [string] :license Include project license data
+    # @param  options [string] :statistics Include project statistics.
+    # @param  options [string] :with_custom_attributes Include custom attributes in response. (admins only)
     # @return [Gitlab::ObjectifiedHash]
-    def project(id)
-      get("/projects/#{url_encode id}")
+    def project(id, options = {})
+      get("/projects/#{url_encode id}", query: options)
     end
 
     # Creates a new project.
@@ -640,5 +643,146 @@ class Gitlab::Client
     def unarchive_project(id)
       post("/projects/#{url_encode id}/unarchive")
     end
+
+    # Gets project custom_attributes.
+    #
+    # @example
+    #   Gitlab.project_custom_attributes(2)
+    #
+    # @param  [Integer] project_id The ID of a project.
+    # @return [Gitlab::ObjectifiedHash]
+    def project_custom_attributes(project_id)
+      get("/projects/#{project_id}/custom_attributes")
+    end
+
+    # Gets single project custom_attribute.
+    #
+    # @example
+    #   Gitlab.project_custom_attribute(key, 2)
+    #
+    # @param  [String] key The custom_attributes key
+    # @param  [Integer] project_id The ID of a project.
+    # @return [Gitlab::ObjectifiedHash]
+    def project_custom_attribute(key, project_id)
+      get("/projects/#{project_id}/custom_attributes/#{key}")
+    end
+
+    # Creates a new custom_attribute
+    #
+    # @example
+    #   Gitlab.add_custom_attribute('some_new_key', 'some_new_value', 2)
+    #
+    # @param  [String] key The custom_attributes key
+    # @param  [String] value The custom_attributes value
+    # @param  [Integer] project_id The ID of a project.
+    # @return [Gitlab::ObjectifiedHash]
+    def add_project_custom_attribute(key, value, project_id)
+      url = "/projects/#{project_id}/custom_attributes/#{key}"
+      put(url, body: { value: value })
+    end
+
+    # Delete custom_attribute
+    # Will delete a custom_attribute
+    #
+    # @example
+    #   Gitlab.delete_project_custom_attribute('somekey', 2)
+    #
+    # @param  [String] key The custom_attribute key to delete
+    # @param  [Integer] project_id The ID of a project.
+    # @return [Boolean]
+    def delete_project_custom_attribute(key, project_id = nil)
+      delete("/projects/#{project_id}/custom_attributes/#{key}")
+    end
+
+    # List project deploy tokens
+    #
+    # @example
+    #   Gitlab.project_deploy_tokens(42)
+    #
+    # @param [Integer, String] id The ID or path of a project.
+    # @option options [Boolean] :active Limit by active status. Optional.
+    def project_deploy_tokens(project, options = {})
+      get("/projects/#{url_encode project}/deploy_tokens", query: options)
+    end
+
+    # Get languages used with percentage value
+    #
+    # @example
+    #   Gitlab.project_languages(42)
+    #
+    # @param [Integer, String] id The ID or path of a project.
+    # @return [Gitlab::ObjectifiedHash]
+    def project_languages(project)
+      get("/projects/#{url_encode project}/languages")
+    end
+
+    # List all project access tokens.
+    #
+    # @example
+    #   Gitlab.project_access_tokens(42)
+    #
+    # @param [Integer, String] project The ID or path of a project.
+    # @option options [String] :state Limit by active/inactive state. Optional.
+    #
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def project_access_tokens(project, options = {})
+      get("/projects/#{url_encode project}/access_tokens", query: options)
+    end
+
+    # Get a specific project access token.
+    #
+    # @example
+    #   Gitlab.project_access_token(42, 1234)
+    #
+    # @param [Integer, String] project The ID or path of a project.
+    # @param [Integer] token_id The ID of the project access token.
+    #
+    # @return [Gitlab::ObjectifiedHash] Information about the specified project access token.
+    def project_access_token(project, token_id)
+      get("/projects/#{url_encode project}/access_tokens/#{token_id}")
+    end
+
+    # Creates a new project access token.
+    #
+    # @example
+    #   Gitlab.create_project_access_token(42, 'My Token', ['api'], '2024-12-12', access_level: 40)
+    #
+    # @param  [Integer, String] project The ID or path of a project.
+    # @param  [String] name The name of the project access token.
+    # @param  [Array] scopes List of scopes of the project access token.
+    # @param  [String] expires_at A date string in the format YYYY-MM-DD.
+    # @option options [Integer] :access_level Access level. Optional. Defaults to 40.
+    #
+    # @return [Gitlab::ObjectifiedHash] Information about the created project access token.
+    def create_project_access_token(project, name, scopes, expires_at, options = {})
+      post("/projects/#{url_encode project}/access_tokens", body: { name: name, scopes: scopes, expires_at: expires_at }.merge(options))
+    end
+
+    # Rotate a project access token.
+    #
+    # @example
+    #   Gitlab.rotate_project_access_token(42, 1234)
+    #
+    # @param [Integer, String] project The ID or path of a project.
+    # @param [Integer] token_id The ID of the project access token.
+    # @option options [String] :expires_at A date string in the format YEAR-MONTH-DAY.
+    #
+    # @return [Gitlab::ObjectifiedHash] Information about the specified project access token.
+    def rotate_project_access_token(project, token_id, options = {})
+      post("/projects/#{url_encode project}/access_tokens/#{token_id}/rotate", query: options)
+    end
+
+    # Revoke a project access token.
+    #
+    # @example
+    #   Gitlab.revoke_project_access_token(42, 1234)
+    #
+    # @param [Integer, String] project The ID or path of a project.
+    # @param [Integer] token_id The ID of the project access token.
+    #
+    # @return [Gitlab::ObjectifiedHash]
+    def revoke_project_access_token(project, token_id)
+      delete("/projects/#{url_encode project}/access_tokens/#{token_id}")
+    end
   end
 end
