@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-describe Gitlab::Client do
+RSpec.describe Gitlab::Client do
   describe '.file_contents' do
     before do
       stub_get('/projects/3/repository/files/Gemfile/raw?ref=master', 'raw_file.txt')
@@ -52,8 +52,11 @@ describe Gitlab::Client do
 
   describe '.create_file' do
     let(:api_path) { '/projects/3/repository/files/path' }
-    let!(:request_stub) { stub_post(api_path, 'repository_file') }
-    let!(:file) { Gitlab.create_file(3, 'path', 'branch', 'content', 'commit message', author_name: 'joe') }
+
+    before do
+      stub_post(api_path, 'repository_file')
+      @file = Gitlab.create_file(3, 'path', 'branch', 'content', 'commit message', author_name: 'joe')
+    end
 
     it 'creates the correct resource' do
       expected_parameters = {
@@ -65,15 +68,18 @@ describe Gitlab::Client do
     end
 
     it 'returns information about the new file' do
-      expect(file.file_path).to eq 'path'
-      expect(file.branch_name).to eq 'branch'
+      expect(@file.file_path).to eq 'path'
+      expect(@file.branch_name).to eq 'branch'
     end
   end
 
   describe '.edit_file' do
     let(:api_path) { '/projects/3/repository/files/path' }
-    let!(:request_stub) { stub_put(api_path, 'repository_file') }
-    let!(:file) { Gitlab.edit_file(3, 'path', 'branch', 'content', 'commit message', author_name: 'joe') }
+
+    before do
+      stub_put(api_path, 'repository_file')
+      @file = Gitlab.edit_file(3, 'path', 'branch', 'content', 'commit message', author_name: 'joe')
+    end
 
     it 'updates the correct resource' do
       expected_parameters = {
@@ -85,15 +91,18 @@ describe Gitlab::Client do
     end
 
     it 'returns information about the new file' do
-      expect(file.file_path).to eq 'path'
-      expect(file.branch_name).to eq 'branch'
+      expect(@file.file_path).to eq 'path'
+      expect(@file.branch_name).to eq 'branch'
     end
   end
 
   describe '.remove_file' do
     let(:api_path) { '/projects/3/repository/files/path' }
-    let!(:request_stub) { stub_delete(api_path, 'repository_file') }
-    let!(:file) { Gitlab.remove_file(3, 'path', 'branch', 'commit message', author_name: 'joe') }
+
+    before do
+      stub_delete(api_path, 'repository_file')
+      @file = Gitlab.remove_file(3, 'path', 'branch', 'commit message', author_name: 'joe')
+    end
 
     it 'updates the correct resource' do
       expected_parameters = {
@@ -105,8 +114,8 @@ describe Gitlab::Client do
     end
 
     it 'returns information about the new file' do
-      expect(file.file_path).to eq 'path'
-      expect(file.branch_name).to eq 'branch'
+      expect(@file.file_path).to eq 'path'
+      expect(@file.branch_name).to eq 'branch'
     end
   end
 end
